@@ -13,6 +13,6 @@ def get_client(config: Dict[str, str]):
         "sqs",
         aws_access_key_id=config.get("aws_access_key_id"),
         aws_secret_access_key=config.get("aws_secret_access_key"),
-        region_name=config.get("region_name"),
-        endpoint_url="https://sqs.{}.amazonaws.com".format(config.get("region_name"))
+        region_name=config["region_name"],
+        endpoint_url="https://sqs.{}.amazonaws.com".format(config["region_name"])
     )
